@@ -173,7 +173,9 @@ projectRaster <- function(from, to, res, crs, method="bilinear", filename="", ..
 	
 	if (.doCluster()) {
 		
-		cl <- .makeCluster()
+		cl <- .getCluster()
+		on.exit( .returnCluster(cl) )
+
 		nodes <- min(ceiling(to@nrows/10), length(cl)) # at least 10 rows per node
 		
 		cat('Using cluster with', nodes, 'nodes\n')
@@ -221,9 +223,7 @@ projectRaster <- function(from, to, res, crs, method="bilinear", filename="", ..
 				}
 				pbStep(pb)
 			}
-		}
-		
-		stopCluster(cl)
+		}	
 		
 		
 	} else {
